@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: warp
 version: 3.2.3
-id: warp-3.2.3-e779983be81de2d2755ab5db7108dace
-key: warp_04jMAHHVXkrBng0MoECBxW
+id: warp-3.2.3-b193a405602f21fe67837dcb996939ee
+key: warp_34gPYYxNi5M5hgmECVctSj
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -48,7 +48,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.3
-hs-libraries: HSwarp-3.2.3-04jMAHHVXkrBng0MoECBxW
+hs-libraries: HSwarp-3.2.3-34gPYYxNi5M5hgmECVctSj
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
@@ -59,9 +59,9 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    http-date-0.0.6.1-7c047cec0be0c1e5b3b7ae487c34e1e4
+    http-date-0.0.6.1-ba351a4841239284d88745a26c501ccf
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
-    http2-1.5.1-412270c75eeac0f5044d57dcaa27a692
+    http2-1.5.2-c17f65710580a09ffe9d21de5a311fa3
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
